Template

Struct Template 

pub struct Template { /* private fields */ }
Struct representing a rust_html template. Enables easy reusability and injection safety.

Create one using the rust_html::rhtml! macro:

use rust_html::{rhtml, Template};
let my_template: Template = rhtml! { "<div>Hello!</div> "};

You can convert a template to a HTML string:

use rust_html::{rhtml, Template};
let template = rhtml! { "<div>hello, world</div>"};
let html: String = template.into();

You should typically only do this just before returning the HTML in your endpoint.

Implementations

Source

impl Template

pub fn build_internal( template_parts: Vec<(&'static str, Template)>, template_end: &'static str, ) -> Self

Internal macro creation of a rust_html template.

DO NOT USE THIS. USE THE rhtml! MACRO.

This implementation is low level and intended to be used by the rust_html_macros crate.